/*
 * Example for CLICKNAME click
 *
 * Date         DATE
 * Author       SW_ENG
 *
 * Test configuration FT900x :
 *  MCU           :	FT900
 *  Dev. Board    :	EasyFT90x
 *  SW            :	mikroC PRO for FT90x vFT90x_COMPLIER_VER
 *
 * Description :
 *
 *            .... .... .... Describe example .... .... ....
 *
 ******************************************************************************/
#include "winc1500_api.h"   // primary WINC1500 include file
#include "demo_config.h"    // selects which demo to run

sbit WIFI_7_RST at GPIO_PIN1_bit;
sbit WIFI_7_EN  at GPIO_PIN56_bit;
sbit WIFI_7_CS  at GPIO_PIN28_bit;


static void systemInit( void )
{
    GPIO_Digital_Output( &GPIO_PORT_00_07, _GPIO_PINMASK_1 );
    GPIO_Digital_Output( &GPIO_PORT_56_63, _GPIO_PINMASK_0 );
    GPIO_Digital_Output( &GPIO_PORT_24_31, _GPIO_PINMASK_4 );

    UART1_Init( 115200 );

    SPIM1_Init_Advanced( _SPI_MASTER_CLK_RATIO_64, _SPI_CFG_PHASE_CAPTURE_RISING |
		         _SPI_CFG_POLARITY_IDLE_LOW | _SPI_CFG_SS_AUTO_DISABLE |
		         _SPI_CFG_FIFO_DISABLE, _SPI_SS_LINE_NONE );

    IRQ_CTRL.B31 = 0;
    GPIO03_CFG0_bit = 1;
    GPIO03_CFG1_bit = 1;
    GPIO03_CFG2_bit = 0;
    GPIO03_CFG3_bit = 0;
    GPIO_INT_EN3_bit = 1;
    TIMER_CONTROL_0 = 2;
    TIMER_SELECT = 0;
    TIMER_PRESC_LS = 80;
    TIMER_PRESC_MS = 195;
    TIMER_WRITE_LS = 1;
    TIMER_WRITE_MS = 0;
    TIMER_CONTROL_3 = 0;
    TIMER_CONTROL_4 |= 17;
    TIMER_CONTROL_2 |= 16;
    TIMER_INT |= 2;
    TIMER_CONTROL_1 |= 1;
}

void m2mStub_EintEnable( void )
{
    GPIO_INT_EN3_bit = 1;
}

void m2mStub_EintDisable( void )
{
    GPIO_INT_EN3_bit = 0;
}

void main(void)
{
    systemInit();

#if defined(USING_PICTAIL)
    printf("Project built for PICtail\r\n");
#elif defined(USING_CLICK_BOARD)
    printf("Project built for Click Board\r\n");
#endif

    printf("Starting driver initialization...\r\n");
    hal_wifi7_init();
    m2m_wifi_init();

    while (1)
    {
        ApplicationTask();
        m2m_wifi_task();
    }
}

void ext_ISR() iv IVT_GPIO_IRQ ics ICS_AUTO
{
    m2m_EintHandler();
    GPIO_INT_PEND3_bit = 1;
}

void Timer2_interrupt() iv IVT_TIMERS_IRQ
{
    if (TIMER_INT_A_bit)
    {
        TIMER_INT = (TIMER_INT & 0xAA) | (1 << 0);
    }
    hal_wifi7_tick();
}

/************************************************************ END OF FILE *****/
